/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                              **** ESPAOL ****
/*
/*                     Ciclo escolar evaluado: 2012 - 2013
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE ESPAOL
/*                                  EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2013_Alum_Esp.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2013_Alum_Esp.txt
/*         as como el archivo Excale06_2013_Alum_Esp.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2013_Alum_Esp.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2013_Alum_Esp.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 12 DE DICIEMBRE DEL 2014
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale06_2013_Alum_Esp.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $entestF    "999"     ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadCF      1         ="11 aos o menos"
                       2         ="12 aos"
                       3         ="13 aos"
                       4         ="14 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadNF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edadAF      0         ="Sin edad anticipada"
                       1         ="Edad anticipada"
                       9         ="Respuesta omitida";
     VALUE edadEF      0         ="Sin extra edad severa"
                       1         ="Extra edad severa"
                       9         ="Respuesta omitida";
     VALUE docenF      99999     ="Respuesta omitida";
     VALUE reactF      0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE nvlF        1         ="Por debajo del nivel bsico"
                       2         ="Bsico"
                       3         ="Medio"
                       4         ="Avanzado";
     VALUE nvblF       0         ="Por debajo del nivel bsico"
                       1         ="Al menos el nivel bsico";
     VALUE nvmlF       0         ="Por debajo del nivel medio"
                       1         ="Al menos el nivel medio";
RUN;



DATA INEE.Excale06_2013_Alum_Esp;
   LENGTH
       NACIONAL         3
       ESCUELA          4
       ID_ENT           3
       NOM_ENT          $19
       ID_MOD           3
       MOD              $4
       ESTRATO          $7
       ENTEST           $6
       ALUMNO           5
       ID_INSTR         $15
       SEXO             3
       EDAD_AC          3
       MES_NAC          3
       EDAD             8
       EDAD_ACC         3
       EDAD_N           3
       EDAD_ANT         3
       EDAD_EES         3
       W_ALU            8
       DOCENTE          5
       PEA_01           3
       PEA_02           3
       PEA_03           3
       PEA_04           3
       PEA_05           3
       PEA_06           3
       PEA_07           3
       PEA_08           3
       PEA_09           3
       PEA_10           3
       PEA_11           3
       PEA_12           3
       PEA_13           3
       PEA_14           3
       PEA_15           3
       PEA_16           3
       PEB_01           3
       PEB_02           3
       PEB_03           3
       PEB_04           3
       PEB_05           3
       PEB_06           3
       PEB_07           3
       PEB_08           3
       PEB_09           3
       PEB_10           3
       PEB_11           3
       PEB_12           3
       PEB_13           3
       PEB_14           3
       PEB_15           3
       PEB_16           3
       PEC_01           3
       PEC_02           3
       PEC_03           3
       PEC_04           3
       PEC_05           3
       PEC_06           3
       PEC_07           3
       PEC_08           3
       PEC_09           3
       PEC_10           3
       PEC_11           3
       PEC_12           3
       PEC_13           3
       PEC_14           3
       PEC_15           3
       PEC_16           3
       PED_01           3
       PED_02           3
       PED_03           3
       PED_04           3
       PED_05           3
       PED_06           3
       PED_07           3
       PED_08           3
       PED_09           3
       PED_10           3
       PED_11           3
       PED_12           3
       PED_13           3
       PED_14           3
       PED_15           3
       PEE_01           3
       PEE_02           3
       PEE_03           3
       PEE_04           3
       PEE_05           3
       PEE_06           3
       PEE_07           3
       PEE_08           3
       PEE_09           3
       PEE_10           3
       PEE_11           3
       PEE_12           3
       PEE_13           3
       PEE_14           3
       PEE_15           3
       PEF_01           3
       PEF_02           3
       PEF_03           3
       PEF_04           3
       PEF_05           3
       PEF_06           3
       PEF_07           3
       PEF_08           3
       PEF_09           3
       PEF_10           3
       PEF_11           3
       PEF_12           3
       PEF_13           3
       PEF_14           3
       PEF_15           3
       PEF_16           3
       PV1ESP           8
       PV2ESP           8
       PV3ESP           8
       PV4ESP           8
       PV5ESP           8
       ESPNVL1          3
       ESPNVL2          3
       ESPNVL3          3
       ESPNVL4          3
       ESPNVL5          3
       ESPNVBL1         3
       ESPNVBL2         3
       ESPNVBL3         3
       ESPNVBL4         3
       ESPNVBL5         3
       ESPNVML1         3
       ESPNVML2         3
       ESPNVML3         3
       ESPNVML4         3
       ESPNVML5         3
       WVARSTRR         3
       W_FSTR1          8
       W_FSTR2          8
       W_FSTR3          8
       W_FSTR4          8
       W_FSTR5          8
       W_FSTR6          8
       W_FSTR7          8
       W_FSTR8          8
       W_FSTR9          8
       W_FSTR10         8
       W_FSTR11         8
       W_FSTR12         8
       W_FSTR13         8
       W_FSTR14         8
       W_FSTR15         8
       W_FSTR16         8
       W_FSTR17         8
       W_FSTR18         8
       W_FSTR19         8
       W_FSTR20         8
       W_FSTR21         8
       W_FSTR22         8
       W_FSTR23         8
       W_FSTR24         8
       W_FSTR25         8
       W_FSTR26         8
       W_FSTR27         8
       W_FSTR28         8
       W_FSTR29         8
       W_FSTR30         8
       W_FSTR31         8
       W_FSTR32         8
       W_FSTR33         8
       W_FSTR34         8
       W_FSTR35         8
       W_FSTR36         8
       W_FSTR37         8
       W_FSTR38         8
       W_FSTR39         8
       W_FSTR40         8
       W_FSTR41         8
       W_FSTR42         8
       W_FSTR43         8
       W_FSTR44         8
       W_FSTR45         8
       W_FSTR46         8
       W_FSTR47         8
       W_FSTR48         8
       W_FSTR49         8
       W_FSTR50         8
       W_FSTR51         8
       W_FSTR52         8
       W_FSTR53         8
       W_FSTR54         8
       W_FSTR55         8
       W_FSTR56         8
       W_FSTR57         8
       W_FSTR58         8
       W_FSTR59         8
       W_FSTR60         8
       W_FSTR61         8
       W_FSTR62         8
       W_FSTR63         8
       W_FSTR64         8
       W_FSTR65         8
       W_FSTR66         8
       W_FSTR67         8
       W_FSTR68         8
       W_FSTR69         8
       W_FSTR70         8
       W_FSTR71         8
       W_FSTR72         8
       W_FSTR73         8
       W_FSTR74         8
       W_FSTR75         8
       W_FSTR76         8
       W_FSTR77         8
       W_FSTR78         8
       W_FSTR79         8
       W_FSTR80         8
       W_FSTR81         8
       W_FSTR82         8
       W_FSTR83         8
       W_FSTR84         8
       W_FSTR85         8
       W_FSTR86         8
       W_FSTR87         8
       W_FSTR88         8
       W_FSTR89         8
       W_FSTR90         8
       W_FSTR91         8
       W_FSTR92         8
       W_FSTR93         8
       W_FSTR94         8
       W_FSTR95         8
       W_FSTR96         8
       W_FSTR97         8
       W_FSTR98         8
       W_FSTR99         8
       W_FSTR100        8

 ;



INFILE alum MISSOVER LINESIZE = 1351;
   INPUT
      NACIONAL              1 - 1
      ESCUELA               2 - 5
      ID_ENT                6 - 7
      NOM_ENT               8 - 26
      ID_MOD               27 - 27
      MOD                  28 - 31
      ESTRATO              32 - 38
      ENTEST               39 - 43
      ALUMNO               44 - 48
      ID_INSTR             49 - 63
      SEXO                 64 - 64
      EDAD_AC              65 - 66
      MES_NAC              67 - 68
      EDAD                 69 - 79
      EDAD_ACC             80 - 80
      EDAD_N               81 - 81
      EDAD_ANT             82 - 82
      EDAD_EES             83 - 83
      W_ALU                84 - 94
      DOCENTE              95 - 99
      PEA_01              100 - 100
      PEA_02              101 - 101
      PEA_03              102 - 102
      PEA_04              103 - 103
      PEA_05              104 - 104
      PEA_06              105 - 105
      PEA_07              106 - 106
      PEA_08              107 - 107
      PEA_09              108 - 108
      PEA_10              109 - 109
      PEA_11              110 - 110
      PEA_12              111 - 111
      PEA_13              112 - 112
      PEA_14              113 - 113
      PEA_15              114 - 114
      PEA_16              115 - 115
      PEB_01              116 - 116
      PEB_02              117 - 117
      PEB_03              118 - 118
      PEB_04              119 - 119
      PEB_05              120 - 120
      PEB_06              121 - 121
      PEB_07              122 - 122
      PEB_08              123 - 123
      PEB_09              124 - 124
      PEB_10              125 - 125
      PEB_11              126 - 126
      PEB_12              127 - 127
      PEB_13              128 - 128
      PEB_14              129 - 129
      PEB_15              130 - 130
      PEB_16              131 - 131
      PEC_01              132 - 132
      PEC_02              133 - 133
      PEC_03              134 - 134
      PEC_04              135 - 135
      PEC_05              136 - 136
      PEC_06              137 - 137
      PEC_07              138 - 138
      PEC_08              139 - 139
      PEC_09              140 - 140
      PEC_10              141 - 141
      PEC_11              142 - 142
      PEC_12              143 - 143
      PEC_13              144 - 144
      PEC_14              145 - 145
      PEC_15              146 - 146
      PEC_16              147 - 147
      PED_01              148 - 148
      PED_02              149 - 149
      PED_03              150 - 150
      PED_04              151 - 151
      PED_05              152 - 152
      PED_06              153 - 153
      PED_07              154 - 154
      PED_08              155 - 155
      PED_09              156 - 156
      PED_10              157 - 157
      PED_11              158 - 158
      PED_12              159 - 159
      PED_13              160 - 160
      PED_14              161 - 161
      PED_15              162 - 162
      PEE_01              163 - 163
      PEE_02              164 - 164
      PEE_03              165 - 165
      PEE_04              166 - 166
      PEE_05              167 - 167
      PEE_06              168 - 168
      PEE_07              169 - 169
      PEE_08              170 - 170
      PEE_09              171 - 171
      PEE_10              172 - 172
      PEE_11              173 - 173
      PEE_12              174 - 174
      PEE_13              175 - 175
      PEE_14              176 - 176
      PEE_15              177 - 177
      PEF_01              178 - 178
      PEF_02              179 - 179
      PEF_03              180 - 180
      PEF_04              181 - 181
      PEF_05              182 - 182
      PEF_06              183 - 183
      PEF_07              184 - 184
      PEF_08              185 - 185
      PEF_09              186 - 186
      PEF_10              187 - 187
      PEF_11              188 - 188
      PEF_12              189 - 189
      PEF_13              190 - 190
      PEF_14              191 - 191
      PEF_15              192 - 192
      PEF_16              193 - 193
      PV1ESP              194 - 201
      PV2ESP              202 - 209
      PV3ESP              210 - 217
      PV4ESP              218 - 225
      PV5ESP              226 - 233
      ESPNVL1             234 - 234
      ESPNVL2             235 - 235
      ESPNVL3             236 - 236
      ESPNVL4             237 - 237
      ESPNVL5             238 - 238
      ESPNVBL1            239 - 239
      ESPNVBL2            240 - 240
      ESPNVBL3            241 - 241
      ESPNVBL4            242 - 242
      ESPNVBL5            243 - 243
      ESPNVML1            244 - 244
      ESPNVML2            245 - 245
      ESPNVML3            246 - 246
      ESPNVML4            247 - 247
      ESPNVML5            248 - 248
      WVARSTRR            249 - 251
      W_FSTR1             252 - 262
      W_FSTR2             263 - 273
      W_FSTR3             274 - 284
      W_FSTR4             285 - 295
      W_FSTR5             296 - 306
      W_FSTR6             307 - 317
      W_FSTR7             318 - 328
      W_FSTR8             329 - 339
      W_FSTR9             340 - 350
      W_FSTR10            351 - 361
      W_FSTR11            362 - 372
      W_FSTR12            373 - 383
      W_FSTR13            384 - 394
      W_FSTR14            395 - 405
      W_FSTR15            406 - 416
      W_FSTR16            417 - 427
      W_FSTR17            428 - 438
      W_FSTR18            439 - 449
      W_FSTR19            450 - 460
      W_FSTR20            461 - 471
      W_FSTR21            472 - 482
      W_FSTR22            483 - 493
      W_FSTR23            494 - 504
      W_FSTR24            505 - 515
      W_FSTR25            516 - 526
      W_FSTR26            527 - 537
      W_FSTR27            538 - 548
      W_FSTR28            549 - 559
      W_FSTR29            560 - 570
      W_FSTR30            571 - 581
      W_FSTR31            582 - 592
      W_FSTR32            593 - 603
      W_FSTR33            604 - 614
      W_FSTR34            615 - 625
      W_FSTR35            626 - 636
      W_FSTR36            637 - 647
      W_FSTR37            648 - 658
      W_FSTR38            659 - 669
      W_FSTR39            670 - 680
      W_FSTR40            681 - 691
      W_FSTR41            692 - 702
      W_FSTR42            703 - 713
      W_FSTR43            714 - 724
      W_FSTR44            725 - 735
      W_FSTR45            736 - 746
      W_FSTR46            747 - 757
      W_FSTR47            758 - 768
      W_FSTR48            769 - 779
      W_FSTR49            780 - 790
      W_FSTR50            791 - 801
      W_FSTR51            802 - 812
      W_FSTR52            813 - 823
      W_FSTR53            824 - 834
      W_FSTR54            835 - 845
      W_FSTR55            846 - 856
      W_FSTR56            857 - 867
      W_FSTR57            868 - 878
      W_FSTR58            879 - 889
      W_FSTR59            890 - 900
      W_FSTR60            901 - 911
      W_FSTR61            912 - 922
      W_FSTR62            923 - 933
      W_FSTR63            934 - 944
      W_FSTR64            945 - 955
      W_FSTR65            956 - 966
      W_FSTR66            967 - 977
      W_FSTR67            978 - 988
      W_FSTR68            989 - 999
      W_FSTR69           1000 - 1010
      W_FSTR70           1011 - 1021
      W_FSTR71           1022 - 1032
      W_FSTR72           1033 - 1043
      W_FSTR73           1044 - 1054
      W_FSTR74           1055 - 1065
      W_FSTR75           1066 - 1076
      W_FSTR76           1077 - 1087
      W_FSTR77           1088 - 1098
      W_FSTR78           1099 - 1109
      W_FSTR79           1110 - 1120
      W_FSTR80           1121 - 1131
      W_FSTR81           1132 - 1142
      W_FSTR82           1143 - 1153
      W_FSTR83           1154 - 1164
      W_FSTR84           1165 - 1175
      W_FSTR85           1176 - 1186
      W_FSTR86           1187 - 1197
      W_FSTR87           1198 - 1208
      W_FSTR88           1209 - 1219
      W_FSTR89           1220 - 1230
      W_FSTR90           1231 - 1241
      W_FSTR91           1242 - 1252
      W_FSTR92           1253 - 1263
      W_FSTR93           1264 - 1274
      W_FSTR94           1275 - 1285
      W_FSTR95           1286 - 1296
      W_FSTR96           1297 - 1307
      W_FSTR97           1308 - 1318
      W_FSTR98           1319 - 1329
      W_FSTR99           1330 - 1340
      W_FSTR100          1341 - 1351
;




   LABEL
      NACIONAL         = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA          = "Identificador de la escuela"
      ID_ENT           = "Entidad federativa (identificador numrico)"
      NOM_ENT          = "Entidad federativa"
      ID_MOD           = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD              = "Estrato escolar o Modalidad educativa"
      ESTRATO          = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST           = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO           = "Identificador del alumno"
      ID_INSTR         = "Identificador del cuadernillo de examen"
      SEXO             = "Sexo del alumno"
      EDAD_AC          = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC          = "Mes de nacimiento del alumno"
      EDAD             = "Edad del alumno al mes de mayo de 2013, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC         = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N           = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT         = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES         = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU            = "Peso muestral o ponderador del alumno"
      DOCENTE          = "Identificador del docente que imparte clases al alumno"
      PEA_01           = "Identificar la relacin causa y efecto en un texto expositivo."
      PEA_02           = "Identificar los nexos que introducen secuencias lgicas de ideas."
      PEA_03           = "Identificar la diferencia en contenido entre dos textos expositivos que tratan un mismo tema."
      PEA_04           = "Identificar los elementos genricos de una referencia bibliogrfica."
      PEA_05           = "Seleccionar fuentes de consulta para hacer correcciones ortogrficas."
      PEA_06           = "Identificar el propsito de una descripcin dentro de un cuento de terror."
      PEA_07           = "Inferir las emociones de los personajes dentro de un cuento de terror."
      PEA_08           = "Identificar el uso de recursos literarios en una descripcin que aparece en un cuento de terror."
      PEA_09           = "Identificar un fragmento del cuento en que se genere suspenso y tensin."
      PEA_10           = "Identificar la diferencia en la estructura de una obra de teatro y un cuento (dilogos)."
      PEA_11           = "Identificar los nexos que indiquen suspenso en un cuento de terror."
      PEA_12           = "Identificar las relaciones causa y consecuencia en un relato histrico."
      PEA_13           = "Identificar el orden de los sucesos que se presentan en un relato histrico."
      PEA_14           = "Reconocer las caractersticas del lenguaje formal en un relato histrico."
      PEA_15           = "Identificar el uso de verbos en tiempos pasados que se utilizan para narrar acciones sucesivas y simultneas."
      PEA_16           = "Identificar los nexos que indiquen referencias temporales en un relato histrico."
      PEB_01           = "Identificar el punto de vista del autor en un artculo de opinin."
      PEB_02           = "Identificar la intencin del autor al escribir un artculo de opinin."
      PEB_03           = "Identificar el argumento del autor que justifica su punto de vista expresado en un artculo de opinin."
      PEB_04           = "Identificar los nexos que indiquen los puntos de acuerdo o desacuerdo del autor en un artculo de opinin."
      PEB_05           = "Reconocer las ventajas de hablar ms de un idioma para comunicarse con otros."
      PEB_06           = "Identificar el estilo adecuado para la escritura de un reporte de un experimento."
      PEB_07           = "Reconocer la funcin de una entrevista."
      PEB_08           = "Identificar la funcin de los mapas conceptuales."
      PEB_09           = "Identificar la pregunta pertinente a incluir en un cuestionario."
      PEB_10           = "Identificar el uso de la informacin que se obtiene al aplicar un cuestionario."
      PEB_11           = "Completar informacin en un cuadro sinptico."
      PEB_12           = "Identificar el uso correcto de palabras de la misma familia lxica para guiar decisiones ortogrficas."
      PEB_13           = "Identificar el uso correcto de la cita textual  en una nota enciclopdica."
      PEB_14           = "Identificar el dilogo correcto de acuerdo con la intencin de un personaje."
      PEB_15           = "Identificar las caractersticas fsicas y de personalidad de un personaje."
      PEB_16           = "Identificar las caractersticas psicolgicas de un personaje."
      PEC_01           = "Identificar la conclusin que podra derivarse de un debate."
      PEC_02           = "Seleccionar una opinin fundamentada que puede derivarse de un debate."
      PEC_03           = "Identificar la expresin que incluye una crtica constructiva ante una de las posturas que se muestra en un debate."
      PEC_04           = "Identificar la expresin que incluye un acuerdo tomado dentro de una discusin."
      PEC_05           = "Reconocer el uso correcto de los signos de interrogacin o exclamacin en un dilogo que aparece en un chiste."
      PEC_06           = "Reconocer los elementos convencionales en la edicin de un libro."
      PEC_07           = "Identificar  preguntas  irrelevantes en  una entrevista."
      PEC_08           = "Identificar preguntas relevantes que deben incluirse en la entrevista."
      PEC_09           = "Inferir la conclusin a la que llegara un entrevistado en funcin de la informacin que se solicita."
      PEC_10           = "Identificar el uso correcto de acentos grficos en palabras que introducen preguntas y requieren de acentos diacrticos."
      PEC_11           = "Reconocer la relacin que existe en el destinatario y el remitente en una carta formal."
      PEC_12           = "Interpretar la emocin que transmite un fragmento de una carta formal."
      PEC_13           = "Interpretar el significado de una palabra desconocida mediante el contexto de una carta formal."
      PEC_14           = "Identificar el uso del lenguaje en una carta formal."
      PEC_15           = "Completar la informacin en un instructivo."
      PEC_16           = "Identificar la secuencia de pasos de un instructivo."
      PED_01           = "Identificar las semejanzas entre la moraleja de una fbula y un refrn."
      PED_02           = "Sustituir la moraleja de una fbula por un refrn."
      PED_03           = "Identificar la intencin del autor al escribir una fbula."
      PED_04           = "Identificar el sentido literal que tiene una metfora que aparece en una fbula."
      PED_05           = "Identificar la conclusin que se puede obtener de los datos estadsticos que se presentan en una tabla."
      PED_06           = "Identificar la informacin adicional que aporta una tabla en funcin de la informacin que se presenta en un reportaje."
      PED_07           = "Identificar el  uso de verbos  que introducen el discurso directo en una oracin."
      PED_08           = "Reconocer la funcin que tiene una cita textual que aparece en un reportaje."
      PED_09           = "Identificar el prrafo de una biografa en el que se describe una situacin particular."
      PED_10           = "Identificar la voz narrativa en una biografa."
      PED_11           = "Identificar errores de segmentacin de palabras dentro de un texto."
      PED_12           = "Seleccionar el encabezado de una noticia."
      PED_13           = "Identificar la diferencia entre expresar una opinin y referir un hecho."
      PED_14           = "Distinguir entre datos, argumentos y opiniones."
      PED_15           = "Inferir fechas en los que ocurren los hechos cuando la informacin no es explcita."
      PEE_01           = "Identificar la funcin de un texto argumentativo."
      PEE_02           = "Identificar la estructura de un tipo de texto."
      PEE_03           = "Identificar la funcin de un tipo de texto para integrar informacin sobre un tema."
      PEE_04           = "Identificar la intencin del autor al escribir un texto con funcin informativa."
      PEE_05           = "Identificar la intencin del autor al escribir un texto con funcin apelativa."
      PEE_06           = "Identificar el uso de elementos de realidad y fantasa en un cuento."
      PEE_07           = "Identificar la diferencia entre los fines que tienen dos anuncios que tratan un mismo tema."
      PEE_08           = "Identificar la funcin de un anuncio."
      PEE_09           = "Identificar la funcin persuasiva  de una frase que aparece en un anuncio."
      PEE_10           = "Identificar los elementos persuasivos utilizados en un anuncio."
      PEE_11           = "Identificar la funcin que tienen algunos recursos retricos que se utilizan en un anuncio."
      PEE_12           = "Identificar la parfrasis que recupera el sentido de un prrafo que aparece en un reportaje."
      PEE_13           = "Seleccionar la pregunta que incluya la informacin esencial de un prrafo de un reportaje."
      PEE_14           = "Identificar la relacin entre los datos y los argumentos de un reportaje."
      PEE_15           = "Identificar el uso de un verbo, adverbio, adjetivo o frase proposicional para describir."
      PEF_01           = "Identificar las relaciones causa y consecuencia en un artculo de divulgacin."
      PEF_02           = "Identificar los nexos que indiquen una relacin causa y efecto en un artculo de divulgacin."
      PEF_03           = "Identificar la congruencia entre una imagen y el uso de recursos de apoyo como pies de figura en un artculo de divulgacin."
      PEF_04           = "Reconocer la funcin que tiene una referencia bibliogrfica que aparece en un artculo de divulgacin."
      PEF_05           = "Interpretar el significado de una expresin que aparece en un poema."
      PEF_06           = "Identificar la emocin que expresa la estrofa de un poema."
      PEF_07           = "Identificar el uso de la rima en un poema."
      PEF_08           = "Identificar la expresin que crea un efecto potico."
      PEF_09           = "Identificar el fondo y la forma del verso de un poema."
      PEF_10           = "Identificar la organizacin de las ideas en una entrevista."
      PEF_11           = "Interpretar el sentido de una pregunta que aparece en una entrevista."
      PEF_12           = "Identificar la explicacin que un entrevistado da a un hecho."
      PEF_13           = "Seleccionar fuentes de informacin relevantes para hacer un reportaje."
      PEF_14           = "Elegir el subttulo de una de las secciones de un texto enciclopdico."
      PEF_15           = "Seleccionar el apartado de un texto enciclopdico que presenta informacin especfica."
      PEF_16           = "Valorar  la relevancia de una ilustracin que se presenta en un texto enciclopdico."
      PV1ESP           = "Primer valor plausible de Espaol"
      PV2ESP           = "Segundo valor plausible de Espaol"
      PV3ESP           = "Tercer valor plausible de Espaol"
      PV4ESP           = "Cuarto valor plausible de Espaol"
      PV5ESP           = "Quinto valor plausible de Espaol"
      ESPNVL1          = "Nivel de logro en Espaol. Asociado a PV1ESP. (Cuatro niveles)"
      ESPNVL2          = "Nivel de logro en Espaol. Asociado a PV2ESP. (Cuatro niveles)"
      ESPNVL3          = "Nivel de logro en Espaol. Asociado a PV3ESP. (Cuatro niveles)"
      ESPNVL4          = "Nivel de logro en Espaol. Asociado a PV4ESP. (Cuatro niveles)"
      ESPNVL5          = "Nivel de logro en Espaol. Asociado a PV5ESP. (Cuatro niveles)"
      ESPNVBL1         = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV1ESP."
      ESPNVBL2         = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV2ESP."
      ESPNVBL3         = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV3ESP."
      ESPNVBL4         = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV4ESP."
      ESPNVBL5         = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a PV5ESP."
      ESPNVML1         = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV1ESP."
      ESPNVML2         = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV2ESP."
      ESPNVML3         = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV3ESP."
      ESPNVML4         = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV4ESP."
      ESPNVML5         = "Identifica si el alumno pertenece al menos al nivel medio de logro en Espaol. Asociado a PV5ESP."
      WVARSTRR         = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9          = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99         = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;






   FORMAT
       NACIONAL          1.
       ESCUELA           4.
       ID_ENT            id_entF.
       NOM_ENT           $char19.
       ID_MOD            id_modF.
       MOD               $modF.
       ESTRATO           $char7.
       ENTEST            $entestF.
       ALUMNO            5.
       ID_INSTR          $char15.
       SEXO              sexoF.
       EDAD_AC           edad_acF.
       MES_NAC           mes_nacF.
       EDAD              edadF.
       EDAD_ACC          edadCF.
       EDAD_N            edadNF.
       EDAD_ANT          edadAF.
       EDAD_EES          edadEF.
       DOCENTE           docenF.
       PEA_01            reactF.
       PEA_02            reactF.
       PEA_03            reactF.
       PEA_04            reactF.
       PEA_05            reactF.
       PEA_06            reactF.
       PEA_07            reactF.
       PEA_08            reactF.
       PEA_09            reactF.
       PEA_10            reactF.
       PEA_11            reactF.
       PEA_12            reactF.
       PEA_13            reactF.
       PEA_14            reactF.
       PEA_15            reactF.
       PEA_16            reactF.
       PEB_01            reactF.
       PEB_02            reactF.
       PEB_03            reactF.
       PEB_04            reactF.
       PEB_05            reactF.
       PEB_06            reactF.
       PEB_07            reactF.
       PEB_08            reactF.
       PEB_09            reactF.
       PEB_10            reactF.
       PEB_11            reactF.
       PEB_12            reactF.
       PEB_13            reactF.
       PEB_14            reactF.
       PEB_15            reactF.
       PEB_16            reactF.
       PEC_01            reactF.
       PEC_02            reactF.
       PEC_03            reactF.
       PEC_04            reactF.
       PEC_05            reactF.
       PEC_06            reactF.
       PEC_07            reactF.
       PEC_08            reactF.
       PEC_09            reactF.
       PEC_10            reactF.
       PEC_11            reactF.
       PEC_12            reactF.
       PEC_13            reactF.
       PEC_14            reactF.
       PEC_15            reactF.
       PEC_16            reactF.
       PED_01            reactF.
       PED_02            reactF.
       PED_03            reactF.
       PED_04            reactF.
       PED_05            reactF.
       PED_06            reactF.
       PED_07            reactF.
       PED_08            reactF.
       PED_09            reactF.
       PED_10            reactF.
       PED_11            reactF.
       PED_12            reactF.
       PED_13            reactF.
       PED_14            reactF.
       PED_15            reactF.
       PEE_01            reactF.
       PEE_02            reactF.
       PEE_03            reactF.
       PEE_04            reactF.
       PEE_05            reactF.
       PEE_06            reactF.
       PEE_07            reactF.
       PEE_08            reactF.
       PEE_09            reactF.
       PEE_10            reactF.
       PEE_11            reactF.
       PEE_12            reactF.
       PEE_13            reactF.
       PEE_14            reactF.
       PEE_15            reactF.
       PEF_01            reactF.
       PEF_02            reactF.
       PEF_03            reactF.
       PEF_04            reactF.
       PEF_05            reactF.
       PEF_06            reactF.
       PEF_07            reactF.
       PEF_08            reactF.
       PEF_09            reactF.
       PEF_10            reactF.
       PEF_11            reactF.
       PEF_12            reactF.
       PEF_13            reactF.
       PEF_14            reactF.
       PEF_15            reactF.
       PEF_16            reactF.
       ESPNVL1           nvlF.
       ESPNVL2           nvlF.
       ESPNVL3           nvlF.
       ESPNVL4           nvlF.
       ESPNVL5           nvlF.
       ESPNVBL1          nvblF.
       ESPNVBL2          nvblF.
       ESPNVBL3          nvblF.
       ESPNVBL4          nvblF.
       ESPNVBL5          nvblF.
       ESPNVML1          nvmlF.
       ESPNVML2          nvmlF.
       ESPNVML3          nvmlF.
       ESPNVML4          nvmlF.
       ESPNVML5          nvmlF.
       wvarstrr          3.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  entest = "999" THEN  entest = .S;
   IF  Docente = 99999 THEN  Docente = .S;


   ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
   DO  i=1 TO 5;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;


   ARRAY perdidos3(94)
                PEA_01 PEA_02 PEA_03 PEA_04 PEA_05 PEA_06 PEA_07 PEA_08 PEA_09 PEA_10
                PEA_11 PEA_12 PEA_13 PEA_14 PEA_15 PEA_16 PEB_01 PEB_02 PEB_03 PEB_04
                PEB_05 PEB_06 PEB_07 PEB_08 PEB_09 PEB_10 PEB_11 PEB_12 PEB_13 PEB_14
                PEB_15 PEB_16 PEC_01 PEC_02 PEC_03 PEC_04 PEC_05 PEC_06 PEC_07 PEC_08
                PEC_09 PEC_10 PEC_11 PEC_12 PEC_13 PEC_14 PEC_15 PEC_16 PED_01 PED_02
                PED_03 PED_04 PED_05 PED_06 PED_07 PED_08 PED_09 PED_10 PED_11 PED_12
                PED_13 PED_14 PED_15 PEE_01 PEE_02 PEE_03 PEE_04 PEE_05 PEE_06 PEE_07
                PEE_08 PEE_09 PEE_10 PEE_11 PEE_12 PEE_13 PEE_14 PEE_15 PEF_01 PEF_02
                PEF_03 PEF_04 PEF_05 PEF_06 PEF_07 PEF_08 PEF_09 PEF_10 PEF_11 PEF_12
                PEF_13 PEF_14 PEF_15 PEF_16;
   DO  i=1 TO 94;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
